@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.106_02';
+our $VERSION = '0.106_03';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Thu Sep 20 22:45:34 2018 GMT
+# on Mon Sep 24 12:48:25 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1722,7 +1722,7 @@ __PACKAGE__->status( add => 24968, iridium => 'D', 'Iridium 37', 'Decayed 2018-0
 __PACKAGE__->status( add => 24969, iridium => 'D', 'Iridium 34', 'Decayed 2018-01-08' );
 __PACKAGE__->status( add => 25039, iridium => 'D', 'Iridium 43', 'Decayed 2018-02-11' );
 __PACKAGE__->status( add => 25040, iridium => 'D', 'Iridium 41', 'Decayed 2018-07-28' );
-__PACKAGE__->status( add => 25041, iridium => '-', 'Iridium 40', 'Tumbling' );
+__PACKAGE__->status( add => 25041, iridium => 'D', 'Iridium 40', 'Decayed 2018-09-23' );
 __PACKAGE__->status( add => 25042, iridium => '-', 'Iridium 39', 'Tumbling' );
 __PACKAGE__->status( add => 25043, iridium => '-', 'Iridium 38', 'Tumbling' );
 __PACKAGE__->status( add => 25077, iridium => '-', 'Iridium 42', 'Tumbling' );
@@ -1735,7 +1735,7 @@ __PACKAGE__->status( add => 25108, iridium => 'D', 'Iridium 49', 'Decayed 2018-0
 __PACKAGE__->status( add => 25169, iridium => '+', 'Iridium 52', '' );
 __PACKAGE__->status( add => 25170, iridium => '-', 'Iridium 56', 'Tumbling' );
 __PACKAGE__->status( add => 25171, iridium => '+', 'Iridium 54', '' );
-__PACKAGE__->status( add => 25172, iridium => '-', 'Iridium 50', 'Tumbling' );
+__PACKAGE__->status( add => 25172, iridium => 'D', 'Iridium 50', 'Decayed 2018-09-23' );
 __PACKAGE__->status( add => 25173, iridium => '-', 'Iridium 53', 'Tumbling' );
 __PACKAGE__->status( add => 25262, iridium => '-', 'Iridium 51', 'Tumbling' );
 __PACKAGE__->status( add => 25263, iridium => 'S', 'Iridium 61', '' );
@@ -1785,8 +1785,8 @@ __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-0
 # Summary:
 # Operational [+]: 10
 #       Spare [S]: 13
-#    Tumbling [-]: 39
-#     Decayed [D]: 35
+#    Tumbling [-]: 37
+#     Decayed [D]: 37
 
 1;
 
